@@ -3,7 +3,7 @@
   -------------------
   Export methods for the Recipe class
   -------------------
-  Copyright (c) 2005-2006 David Johnson
+  Copyright (c) 2005-2007 David Johnson
   Please see the header file for copyright and license information.
  ***************************************************************************/
 
@@ -178,11 +178,10 @@ const QString Recipe::recipeHTML()
     html += "</tr>\n\n";
 
     // presort
-    QMap<QString, Grain> gmap;
+    QMultiMap<QString, Grain> gmap;
     foreach (Grain grain, grains_) gmap.insert(grain.name(), grain);
-    grains_ = gmap.values();
 
-    foreach (Grain grain, grains_) {
+    foreach (Grain grain, gmap.values()) {
         html += "<tr>\n<td>" + grain.weight().toString(2) + "</td>\n";
         html += "<td></td>\n";
         html += "<td>" + escape(grain.name()) + "</td>\n";
@@ -201,11 +200,10 @@ const QString Recipe::recipeHTML()
     html += "</tr>\n\n";
 
     // presort
-    QMap<QString, Hop> hmap;
+    QMultiMap<QString, Hop> hmap;
     foreach (Hop hop, hops_) hmap.insert(hop.name(), hop);
-    hops_ = hmap.values();
 
-    foreach (Hop hop, hops_) {
+    foreach (Hop hop, hmap.values()) {
         html += "<tr>\n<td>" + hop.weight().toString(2) + "</td>\n";
         html += "<td></td>\n";
         html += "<td>" + escape(hop.name()) + "</td>\n";
@@ -224,11 +222,10 @@ const QString Recipe::recipeHTML()
     html += "</tr>\n\n";
 
     // presort
-    QMap<QString, Misc> mmap;
+    QMultiMap<QString, Misc> mmap;
     foreach (Misc misc, miscs_) mmap.insert(misc.name(), misc);
-    miscs_ = mmap.values();
 
-    foreach (Misc misc, miscs_) {
+    foreach (Misc misc, mmap) {
         html += "<tr>\n<td>" + misc.quantity().toString(2) + "</td>\n";
         html += "<td></td>\n";
         html += "<td>" + escape(misc.name()) + "</td>\n";
@@ -317,11 +314,11 @@ const QString Recipe::recipeText()
     text += underline("Ingredients");
 
     // grains
-    QMap<QString, Grain> gmap;
+    // using a map will sort the grains
+    QMultiMap<QString, Grain> gmap;
     foreach (Grain grain, grains_) gmap.insert(grain.name(), grain);
-    grains_ = gmap.values();
 
-    foreach (Grain grain, grains_) {
+    foreach (Grain grain, gmap.values()) {
         text += grain.name().leftJustified(30, ' ');
         text += grain.weight().toString(2) + ", ";
         text += grain.useString() + '\n';
@@ -329,11 +326,11 @@ const QString Recipe::recipeText()
     text += '\n';
 
     // hops
-    QMap<QString, Hop> hmap;
+    // using a map will sort the hops
+    QMultiMap<QString, Hop> hmap;
     foreach (Hop hop, hops_) hmap.insert(hop.name(), hop);
-    hops_ = hmap.values();
 
-    foreach (Hop hop, hops_) {
+    foreach (Hop hop, hmap.values()) {
         text += hop.name().leftJustified(30, ' ');
         text += hop.weight().toString(2) + ", ";
         text += hop.form() + ", ";
@@ -342,11 +339,11 @@ const QString Recipe::recipeText()
     text += '\n';
 
     // misc ingredients
-    QMap<QString, Misc> mmap;
+    // using a map will sort the ingredients
+    QMultiMap<QString, Misc> mmap;
     foreach (Misc misc, miscs_) mmap.insert(misc.name(), misc);
-    miscs_ = mmap.values();
 
-    foreach (Misc misc, miscs_) {
+    foreach (Misc misc, mmap.values()) {
         text += misc.name().leftJustified(30, ' ');
         text += misc.quantity().toString(2) + ", ";
         text += misc.notes() + '\n';
