@@ -3,7 +3,7 @@
   -------------------
   Control class for QBrew
   -------------------
-  Copyright (c) 2006 David Johnson
+  Copyright (c) 2006-2007 David Johnson
   Please see the header file for copyright and license information.
 ***************************************************************************/
 
@@ -69,7 +69,7 @@ void QBrew::initialize(const QString &filename)
         QApplication::setStyle(state_.general.lookfeel);
     }
 
-    // initialize UI
+    // setup UI
     ui.setupUi(this);
     initActions();
 
@@ -116,8 +116,6 @@ void QBrew::initialize(const QString &filename)
     // connections
     connect(ui.menuopenrecent, SIGNAL(aboutToShow()),
             this, SLOT(recentMenuShow()));
-    connect(recipe_, SIGNAL(recipeModified()),
-            this, SLOT(recipeModified()));
 
     // other initialization
     initAutoSave();
